/**
 * @file sprmsched01/init.c
 *
 * @brief A init task body for sprmsched01 example.
 *
 */

/*
 *  COPYRIGHT (c) 2016 Kuan-Hsun Chen, TU Dortmund University (TUDo).
 *
 *  The license and distribution terms for this file may be
 *  found in the file LICENSE in this distribution or at
 *  http://www.rtems.com/license/LICENSE.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#define CONFIGURE_INIT
#include "system.h"

#include <rtems/rtems/tasksimpl.h>
#include <rtems/test.h>
#include <rtems/status-checks.h>

const char rtems_test_name[] = "Rate Monotonic 01";

/* Global variables */
rtems_id   Task_id[ 2 ];         /* array of task ids */
rtems_name Task_name[ 2 ];       /* array of task names */
uint32_t tick_per_second;        /* time reference */
int testnumber = 15;                  /* stop condition */

#if 1
rtems_task Init(
	rtems_task_argument argument
)
{
  TEST_BEGIN();
  rtems_status_code status;
  rtems_time_of_day time;


  tick_per_second = rtems_clock_get_ticks_per_second();
  printf("\nTicks per second in your system: %" PRIu32 "\n", tick_per_second);

  Task_name[ 1 ] = rtems_build_name( 'T', 'A', '1', ' ' );
  Task_name[ 2 ] = rtems_build_name( 'T', 'A', '2', ' ' );

  /* Create two tasks */
  status = rtems_task_create(
    Task_name[ 1 ], 2, RTEMS_MINIMUM_STACK_SIZE * 2, RTEMS_DEFAULT_MODES,
    RTEMS_DEFAULT_ATTRIBUTES, &Task_id[ 1 ]
  );
  if ( status != RTEMS_SUCCESSFUL) {
    printf( "rtems_task_create 1 failed with status of %d.\n", status );
    rtems_test_exit(0);
  } 

  status = rtems_task_create(
    Task_name[ 2 ], 5, RTEMS_MINIMUM_STACK_SIZE * 2, RTEMS_DEFAULT_MODES,
    RTEMS_DEFAULT_ATTRIBUTES, &Task_id[ 2 ]
  );
  if ( status != RTEMS_SUCCESSFUL) {
    printf( "rtems_task_create 2 failed with status of %d.\n", status );
    rtems_test_exit(0);
  }

  /* After creating the periods for tasks, start to run them sequencially. */

  status = rtems_task_start( Task_id[ 1 ], Task_1, 1);
  if ( status != RTEMS_SUCCESSFUL) {
    printf( "rtems_task_start 1 failed with status of %d.\n", status );
    rtems_test_exit(0);
  }
  status = rtems_task_start( Task_id[ 2 ], Task_2, 1);
  if ( status != RTEMS_SUCCESSFUL) {
    printf( "rtems_task_start 2 failed with status of %d.\n", status );
    rtems_test_exit(0);
  }

  status = rtems_task_delete( RTEMS_SELF );
}

#endif
